//DiamondPickaxe.cs

//effects
datablock ParticleData(DiamondPickaxeExplosionParticle)
{
   dragCoefficient      = 2;
   gravityCoefficient   = 1.0;
   inheritedVelFactor   = 0.2;
   constantAcceleration = 0.0;
   spinRandomMin = -90;
   spinRandomMax = 90;
   lifetimeMS           = 500;
   lifetimeVarianceMS   = 300;
   textureName          = "base/data/particles/chunk";
   colors[0]     = "0.7 0.7 0.9 0.9";
   colors[1]     = "0.9 0.9 0.9 0.0";
   sizes[0]      = 0.5;
   sizes[1]      = 0.25;
};

datablock ParticleEmitterData(DiamondPickaxeExplosionEmitter)
{
   ejectionPeriodMS = 7;
   periodVarianceMS = 0;
   ejectionVelocity = 8;
   velocityVariance = 1.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 60;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "DiamondPickaxeExplosionParticle";

   uiName = "DiamondPickaxe Hit";
};

datablock ExplosionData(DiamondPickaxeExplosion)
{
   //explosionShape = "";
   lifeTimeMS = 500;

   soundProfile = DiamondPickaxeHitSound;

   particleEmitter = DiamondPickaxeExplosionEmitter;
   particleDensity = 10;
   particleRadius = 0.2;

   faceViewer     = true;
   explosionScale = "1 1 1";

   shakeCamera = true;
   camShakeFreq = "20.0 22.0 20.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.5;
   camShakeRadius = 10.0;

   // Dynamic light
   lightStartRadius = 3;
   lightEndRadius = 0;
   lightStartColor = "00.0 0.2 0.6";
   lightEndColor = "0 0 0";
};


//projectile
AddDamageType("DiamondPickaxe",   '<bitmap:add-ons/Tool_Minecraft_Pickaxes/CI_DiamondPickaxe> %1',    '%2 <bitmap:add-ons/Tool_Minecraft_Pickaxes/CI_DiamondPickaxe> %1',0.75,1);
datablock ProjectileData(DiamondPickaxeProjectile)
{
   directDamage        = 100;
   directDamageType  = $DamageType::DiamondPickaxe;
   radiusDamageType  = $DamageType::DiamondPickaxe;
   explosion           = DiamondPickaxeExplosion;
   //particleEmitter     = as;

   muzzleVelocity      = 50;
   velInheritFactor    = 1;

   armingDelay         = 0;
   lifetime            = 100;
   fadeDelay           = 70;
   bounceElasticity    = 0;
   bounceFriction      = 0;
   isBallistic         = false;
   gravityMod = 0.0;

   hasLight    = false;
   lightRadius = 3.0;
   lightColor  = "0 0 0.5";

   uiName = "DiamondPickaxe Slice";
};


//////////
// item //
//////////
datablock ItemData(DiamondPickaxeItem)
{
	category = "Tool";  // Mission editor category
	className = "Tool"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./models/diamondpick.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Diamond Pickaxe";
	iconName = "./Icon_DiamondPickaxe";
	doColorShift = true;
	colorShiftColor = "0.471 0.471 0.471 1.000";

	 // Dynamic properties defined by the scripts
	image = DiamondPickaxeImage;
	canDrop = true;
};

////////////////
//Tool image//
////////////////
datablock ShapeBaseImageData(DiamondPickaxeImage)
{
   // Basic Item properties
   shapeFile = "./models/diamondpick.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this Tool doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = false;

   eyeOffset = "0 0 0";

   // Add the ToolImage namespace as a parent, ToolImage namespace
   // provides some hooks into the inventory system.
   className = "ToolImage";

   // Projectile && Ammo.
   item = DiamondPickaxeItem;
   ammo = " ";
   projectile = DiamondPickaxeProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = true;
   doRetraction = false;
   //raise your arm up or not
   armReady = true;

   //casing = " ";
   doColorShift = true;
   colorShiftColor = "0.471 0.471 0.471 1.000";

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.5;
	stateTransitionOnTimeout[0]      = "Ready";
	stateSound[0]                    = DiamondPickaxeDrawSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "PreFire";
	stateAllowImageChange[1]         = true;

	stateName[2]			= "PreFire";
	stateScript[2]                  = "onPreFire";
	stateAllowImageChange[2]        = false;
	stateTimeoutValue[2]            = 0.1;
	stateTransitionOnTimeout[2]     = "Fire";

	stateName[3]                    = "Fire";
	stateTransitionOnTimeout[3]     = "CheckFire";
	stateTimeoutValue[3]            = 0.2;
	stateFire[3]                    = true;
	stateAllowImageChange[3]        = false;
	stateSequence[3]                = "Fire";
	stateScript[3]                  = "onFire";
	stateWaitForTimeout[3]		= true;

	stateName[4]			= "CheckFire";
	stateTransitionOnTriggerUp[4]	= "StopFire";
	stateTransitionOnTriggerDown[4]	= "Fire";

	
	stateName[5]                    = "StopFire";
	stateTransitionOnTimeout[5]     = "Ready";
	stateTimeoutValue[5]            = 0.2;
	stateAllowImageChange[5]        = false;
	stateWaitForTimeout[5]		= true;
	stateSequence[5]                = "StopFire";
	stateScript[5]                  = "onStopFire";


};

function DiamondPickaxeImage::onPreFire(%this, %obj, %slot)
{
	%obj.playthread(2, armattack);
}

function DiamondPickaxeImage::onStopFire(%this, %obj, %slot)
{	
	%obj.playthread(2, root);
}

schedule(100,0,DiamondPickaxeZombies);

function DiamondPickaxeImage::onMount(%this,%obj,%slot)
{
  parent::onMount(%this,%obj,%slot);
  if(%obj.getMountedImage(1).getName() $= "DiamondPickaxeBackImage") { %obj.unMountImage(1); }
}

function DiamondPickaxeImage::onUnMount(%this,%obj,%slot)
{
  parent::onUnMount(%this,%obj,%slot);
  %obj.unMountImage(1);
  %obj.mountImage(DiamondPickaxeBackImage,1);
}

function DiamondPickaxeItem::onPickup(%this,%obj,%col,%a)
{
  for(%i=0;%i<%col.getdatablock().maxTools;%i++)
  {
    %item = %col.tool[%i];
    if(%item $= 0 || %item $= "")
    {
      %freeSlot = 1;
      break;
    }
  }
  if(%obj.canpickup && !isobject(%col.getmountedimage(1)) && %freeSlot) { %col.mountimage(DiamondPickaxeBackImage,1); }
  parent::onPickup(%this,%obj,%col,%a);
}

package DiamondPickaxePackage
{
  function servercmdDropTool(%this,%slot)
  {
    if(isobject(%this.player.tool[%slot]) && %this.player.tool[%slot].getname() $= "DiamondPickaxeItem")
    {
      parent::servercmdDropTool(%this,%slot);
      if(isobject(%this.player.getmountedimage(1)) && %this.player.getmountedimage(1).getname() $= "DiamondPickaxeBackImage") { %this.player.schedule(5,unmountimage,1); }
      return;
    }
    parent::servercmdDropTool(%this,%slot);
  }
};
activatepackage(DiamondPickaxePackage);